Welcome to ClientVPS Mirrors

Help for package commonsMath
Type: Package
Title: JAR Files of the Apache Commons Mathematics Library
Version: 1.2.8
Description: 'Java' JAR files for the Apache Commons Mathematics Library for use by users and other packages.
URL: https://github.com/dbdahl/commonsMath
BugReports: https://github.com/dbdahl/commonsMath/issues
Suggests: rJava (≥ 0.9-10), testthat, knitr, rmarkdown
License: Apache License 2.0 | file LICENSE
VignetteBuilder: knitr
Encoding: UTF-8
RoxygenNote: 7.0.2
NeedsCompilation: no
Packaged: 2023-08-17 19:57:10 UTC; dahl
Author: David B. Dahl ORCID iD [cre], The Apache Software Foundation [aut, cph]
Maintainer: David B. Dahl <dahl@stat.byu.edu>
Repository: CRAN
Date/Publication: 2023-08-17 21:12:31 UTC

JAR Files of the Apache Commons Mathematics Library

Description

'Java' JAR files for the Apache Commons Mathematics Library for use by users and other packages.

Details

The DESCRIPTION file:

Package: commonsMath
Type: Package
Title: JAR Files of the Apache Commons Mathematics Library
Version: 1.2.8
Description: 'Java' JAR files for the Apache Commons Mathematics Library for use by users and other packages.
Authors@R: c(person(given="David B.",family="Dahl",role=c("cre"),email="dahl@stat.byu.edu",comment=c(ORCID = "0000-0002-8173-1547")), person(given="The Apache Software Foundation",role=c("aut","cph")))
URL: https://github.com/dbdahl/commonsMath
BugReports: https://github.com/dbdahl/commonsMath/issues
Suggests: rJava (>= 0.9-10), testthat, knitr, rmarkdown
License: Apache License 2.0 | file LICENSE
VignetteBuilder: knitr
Encoding: UTF-8
RoxygenNote: 7.0.2
Author: David B. Dahl [cre] (<https://orcid.org/0000-0002-8173-1547>), The Apache Software Foundation [aut, cph]
Maintainer: David B. Dahl <dahl@stat.byu.edu>

See the package vignette for details on how to access the Apache Commons Math Library using this package.

Examples

if ( interactive() ) vignette("commonsMath")

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.